==> igloo_0_1_2.tar.tgz: igloo_0_1_2/igloo/language/1/barnraiser_01/pol_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');

//HEADER
$lang['hdr_options'] = 							"options";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_poll'] = 							"poll";
$lang['hdr_vote_history'] =						"vote history";
$lang['hdr_my_vote_history'] =					"my vote history";
$lang['hdr_forthcoming_polls'] = 				"forthcoming polls";
$lang['hdr_archive_polls'] = 					"archive polls";
$lang['hdr_options'] = 							"options";


//SUBMIT
$lang['sub_vote'] = 							"vote";
$lang['sub_vote_change'] = 						"change vote";


// ERR
$lang['err_no_polls'] = 						"Sorry, there are no polls available.";


//HREF
$lang['href_add'] = 							"add poll";
$lang['href_list'] = 							"list";
$lang['href_add'] = 							"add poll";
$lang['href_list'] = 							"list";
$lang['href_edit_this'] = 						"edit this";


//BODY TEXT
$lang['txt_end'] = 								"end";
$lang['txt_anonymous'] =						"anonymous";
$lang['txt_edit_poll_option'] =					"edit or delete a poll option";
$lang['txt_start'] = 							"start";
$lang['txt_question'] =							"question";
$lang['txt_required'] =							"required";
$lang['txt_poll_required'] =					"you are required to vote before seeing comments.";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_comment_help'] = 					"Remember to observe the rules of the group. Reply in group language only.";
$lang['sub_check_spelling'] =					"Check Spelling";
$lang['txt_no_comment_allowed'] = 				"Sorry, this item is not open to receive your comments.";
$lang['txt_poll'] = 							"poll"; //breadcrumb

$lang['txt_option_items'] = 					"my polls";
$lang['txt_option_marked'] = 					"marked polls";
$lang['txt_option_tipped'] = 					"tipped polls";
$lang['txt_option_list'] = 						"list polls";
$lang['txt_option_edit'] = 						"edit this poll";
$lang['txt_option_add'] = 						"add a poll";
$lang['txt_option_vote'] = 						"polls i've voted on";

?>

==> igloo_0_1_7.tar.tgz: igloo_0_1_7/igloo/language/1/barnraiser_01/pol_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of Igloo
//
// Copyright (C) 2003, 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');

//HEADER
$lang['hdr_polls'] = 							"polls";
$lang['hdr_poll'] = 							"poll";
$lang['hdr_vote_history'] =						"vote history";
$lang['hdr_my_vote_history'] =					"my vote history";
$lang['hdr_forthcoming_polls'] = 				"forthcoming polls";
$lang['hdr_archive_polls'] = 					"archive polls";
$lang['hdr_my_network_polls'] = 				"latest polls from my network";
$lang['hdr_options'] =							"poll options";
$lang['hdr_poll_author'] = 						"author";


//SUBMIT
$lang['sub_vote'] = 							"vote";
$lang['sub_vote_change'] = 						"change vote";


//HREF
$lang['href_network_poll'] = 					"view their polls";
$lang['href_view_node'] = 						"latest from the group";
$lang['href_view_network'] = 					"latest from my network";
$lang['href_my_polls'] = 						"my polls";
$lang['href_marked'] = 							"marked polls";
$lang['href_add_poll'] = 						"add a poll to my polls";
$lang['href_voted'] = 							"polls i've voted in";
$lang['href_list_polls'] = 						"list polls for this author";


// ERR
$lang['err_no_polls'] = 						"Sorry, there are no polls available.";


//BODY TEXT
$lang['txt_end'] = 								"end";
$lang['txt_anonymous'] =						"anonymous";
$lang['txt_start'] = 							"start";
$lang['txt_question'] =							"question";
$lang['txt_required'] =							"required";
$lang['txt_poll_required'] =					"you are required to vote before seeing comments.";
$lang['txt_published_to'] = 					"Published to";
$lang['txt_tag'] = 								"tags";
$lang['txt_options'] = 							"options";
$lang['txt_view'] = 							"view";
$lang['txt_intro_node'] = 						"Listed are the last MAXLISTNUMBER (max) polls that have been published by a member of this community.";
$lang['txt_intro_network'] = 					"Listed are the last MAXLISTNUMBER (max) polls that have been published by a person in your network.";
$lang['txt_outro_network'] = 					"The following people in your network have not published a poll within the last MAXLISTNUMBER.";
$lang['txt_intro_voted'] = 						"The following polls are polls that have received your vote.";
$lang['txt_poll'] = 							"poll"; //breadcrumb

?>
